@@ -1,6 +1,7 @@
 #include <QApplication>
 #include <QQmlApplicationEngine>
 #include <QCommandLineParser>
+#include <QQmlContext>
 #include <QIcon>
 #include <QDate>
 
@@ -14,6 +15,8 @@
 #include "helpers/station.h"
 #include "helpers/fonts.h"
 
+#include "server/server.h"
+
 #include "../station_version.h"
 
 #define STATION_URI "org.maui.station"
@@ -28,8 +31,6 @@ int main(int argc, char *argv[])
     app.setOrganizationName("Maui");
     app.setWindowIcon(QIcon(":/station/station.svg"));
 
-    MauiApp::instance()->setIconName("qrc:/station/station.svg");
-
     KLocalizedString::setApplicationDomain("station");
     KAboutData about(QStringLiteral("station"), i18n("Station"), STATION_VERSION_STRING, i18n("Convergent terminal emulator."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
@@ -38,9 +39,12 @@ int main(int argc, char *argv[])
     about.setBugAddress("https://invent.kde.org/maui/station/-/issues");
     about.setOrganizationDomain(STATION_URI);
     about.setProgramLogo(app.windowIcon());
+    about.addComponent("QMLTermWidget");
 
     KAboutData::setApplicationData(about);
 
+    MauiApp::instance()->setIconName("qrc:/station/station.svg");
+
     QCommandLineParser parser;
 
     about.setupCommandLine(&parser);
@@ -49,30 +53,54 @@ int main(int argc, char *argv[])
     about.processCommandLine(&parser);
     const QStringList args = parser.positionalArguments();
 
+    QStringList paths;
+    if (!args.isEmpty())
+    {
+        for(const auto &path : args)
+            paths << QUrl::fromUserInput(path).toString();
+    }
+
+    if (AppInstance::attachToExistingInstance(QUrl::fromStringList(paths), false))
+    {
+        // Successfully attached to existing instance of Nota
+        return 0;
+    }
+
+    AppInstance::registerService();
+    auto server = std::make_unique<Server>();
+
     QQmlApplicationEngine engine;
     const QUrl url(QStringLiteral("qrc:/main.qml"));
     QObject::connect(
                 &engine,
                 &QQmlApplicationEngine::objectCreated,
                 &app,
-                [url, args](QObject *obj, const QUrl &objUrl) {
+                [url, args, &server](QObject *obj, const QUrl &objUrl) {
         if (!obj && url == objUrl)
             QCoreApplication::exit(-1);
 
+        server->setQmlObject(obj);
         if (!args.isEmpty())
-            Station::instance()->requestPaths(args);
+            server->openTabs(args, false);
+        else
+        {
+            server->openTabs({"$HOME"}, false);
+        }
+
     },
     Qt::QueuedConnection);
 
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+
     qmlRegisterAnonymousType<Key> (STATION_URI, 1);
     qmlRegisterType<KeysHelper> (STATION_URI, 1, 0, "KeysModel");
     qmlRegisterType<CommandsModel> (STATION_URI, 1, 0, "CommandsModel");
     qmlRegisterSingletonInstance<Station>(STATION_URI, 1, 0, "Station", Station::instance());
     qmlRegisterSingletonType<Fonts>(STATION_URI, 1, 0, "Fonts", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
-           Q_UNUSED(engine)
-           Q_UNUSED(scriptEngine)
-           return new Fonts;
-       });
+        Q_UNUSED(engine)
+        Q_UNUSED(scriptEngine)
+        return new Fonts;
+    });
 
     engine.load(url);
 
